# -*- coding: utf-8 -*-

import sys
from argparse import ArgumentParser
import json
import re

def parse_args():

    p = ArgumentParser(description='JSON to text')

    p.add_argument("--mode", type = int, default = 1, help = "Output mode (0:output keys, 1:output values)")
    p.add_argument("--data_type", type = str, default = "all", help = "type (all, title, ingredients, steps)")
    
    args = p.parse_args()
    
    # check args
    try:
        pass
    except Exception as ex:
        p.print_usage(file=sys.stderr)

    return args

def remove_break(line):
    line = re.sub(u'[\r\n ]+', ' ', line, 10000)
    line = line.strip(" ")
    return line

def output_str(txt_j, txt_e):
    if re.search(u'\S', txt_j) and re.search(u'\S', txt_e):
        print(u"{}\t{}".format(remove_break(txt_j), remove_break(txt_e)))

def output_array(array_j, array_e, tag):
    for elem_j, elem_e in zip(array_j, array_e):
        if isinstance(elem_j, dict) and isinstance(elem_e, dict) and isinstance(elem_j[tag], str) and isinstance(elem_e[tag], str):
            txt_j = elem_j[tag]
            txt_e = elem_e[tag]
            if re.search(u'\S', txt_j) and re.search(u'\S', txt_e):
                if elem_j["position"] != elem_e["position"]:
                    print("position error: {} {}".format(elem_j["position"], elem_e["position"]), file=sys.stderr)
                    exit(1)
                print(u"{}\t{}".format(remove_break(txt_j), remove_break(txt_e)))


def main():
    args = parse_args()

    for line in sys.stdin:
        data_json = json.loads(line)

        if args.mode == 0:
            for lang in data_json["contents"]:
                print(lang)
                for elem in data_json["contents"][lang]:
                    print(elem)
        else:
            if args.data_type == "all":
                output_str(data_json["contents"]["ja"]["title"], data_json["contents"]["en"]["title"])
                output_array(data_json["contents"]["ja"]["ingredients"], data_json["contents"]["en"]["ingredients"], "name")
                output_array(data_json["contents"]["ja"]["steps"], data_json["contents"]["en"]["steps"], "memo")
                  
            elif args.data_type == "title":
                output_str(data_json["contents"]["ja"]["title"], data_json["contents"]["en"]["title"])
                
            elif args.data_type == "ingredients":
                output_array(data_json["contents"]["ja"]["ingredients"], data_json["contents"]["en"]["ingredients"], "name")
                
            elif args.data_type == "steps":
                output_array(data_json["contents"]["ja"]["steps"], data_json["contents"]["en"]["steps"], "memo")
                
if __name__ == '__main__':
  main()

